@@ -4,7 +4,7 @@ import re
 from subprocess import Popen, PIPE
 from collections import OrderedDict, namedtuple
 
-from .config import CONFIG as C
+from .config import get_config
 from .svg_renderer import SvgRenderer
 
 RX_COMMENT_POS = re.compile(r'\s*(\S+)\s+(\S+)')
@@ -41,13 +41,14 @@ class UmlBuilder:
         self.gfx = SvgRenderer(out_path, percent_zoom, bg_color)
         self.warnings = set()
         self.g = {}
+        self.cfg = get_config()
 
     def run(self):
         self.last_cmd = None
         self.objects_dic = CheckedOrderedDict('object', self)
         self.dead_objects_dic = CheckedOrderedDict('object', self)
         self.activity_dic = CheckedOrderedDict('object', self)
-        self.ypos = C.STEP_NORMAL
+        self.ypos = self.cfg.STEP_NORMAL
         self.activity_boxes = []
         self.activity_row = 0
         self.comment_dic = CheckedOrderedDict('comment', self)
@@ -67,7 +68,7 @@ class UmlBuilder:
         self.handle_cmd(None, None)
 
         # close remaining activations
-        self.ypos += C.STEP_NORMAL/2
+        self.ypos += self.cfg.STEP_NORMAL/2
         for name, stack in self.activity_dic.items():
             for i in range(len(stack)):
                 self.inactivate(name)
@@ -101,11 +102,11 @@ class UmlBuilder:
         self.y_max = max(self.y_max, y)
 
     def get_x(self, obj, center=False, activity=False):
-        x = obj.index * (C.COLUMN_WIDTH + C.COLUMN_SPACING)
+        x = obj.index * (self.cfg.COLUMN_WIDTH + self.cfg.COLUMN_SPACING)
         if center:
-            x += C.COLUMN_WIDTH / 2
+            x += self.cfg.COLUMN_WIDTH / 2
         if activity:
-            x += self.nb_active(obj.name) * C.ACTIVITY_WIDTH/2
+            x += self.nb_active(obj.name) * self.cfg.ACTIVITY_WIDTH/2
         return x
 
     def warn(self, cmd, args, warning):
@@ -152,7 +153,7 @@ class UmlBuilder:
 
 
             ypos = self.ypos
-            if cmd == 'actor': ypos += C.ACTOR_DESCENT
+            if cmd == 'actor': ypos += self.cfg.ACTOR_DESCENT
             self.objects_dic[name] = Object(cmd, index, name, label,
                                             ypos, self.activity_row)
             self.activity_dic[name] = []
@@ -164,18 +165,18 @@ class UmlBuilder:
                 if self.activity_row != o.row:
                     continue
                 if o.type == 'actor':
-                    x, y = self.get_x(o, True), self.ypos - C.ACTOR_ASCENT
+                    x, y = self.get_x(o, True), self.ypos - self.cfg.ACTOR_ASCENT
                     self.add(1, self.gfx.actor, x, y)
-                    x, y = self.get_x(o, True), self.ypos + C.ACTOR_LABEL_Y
+                    x, y = self.get_x(o, True), self.ypos + self.cfg.ACTOR_LABEL_Y
                     self.add(1, self.gfx.text, x, y, o.label, middle=True)
                 else:  # regular object
                     x, y = self.get_x(o), self.ypos
                     self.add(1, self.gfx.rect, x, y,
-                             C.COLUMN_WIDTH, C.OBJECT_HEIGHT)
-                    x, y = self.get_x(o, True), self.ypos + C.OBJECT_LABEL_Y
+                             self.cfg.COLUMN_WIDTH, self.cfg.OBJECT_HEIGHT)
+                    x, y = self.get_x(o, True), self.ypos + self.cfg.OBJECT_LABEL_Y
                     self.add(1, self.gfx.text, x, y, o.label,
                              middle=True, underline=True)
-            self.ypos += C.OBJECT_STEP
+            self.ypos += self.cfg.OBJECT_STEP
             self.activity_row += 1
 
     def handle_pobject(self, cmd, args):
@@ -188,7 +189,7 @@ class UmlBuilder:
         if cmd != 'oconstraint': return
         name, text = args
         o = self.objects_dic[name]
-        x, y = self.get_x(o), o.ypos - C.TEXT_MARGIN_Y
+        x, y = self.get_x(o), o.ypos - self.cfg.TEXT_MARGIN_Y
         self.add(1, self.gfx.text, x, y, text)
         return True
 
@@ -196,17 +197,17 @@ class UmlBuilder:
         if cmd != 'lconstraint': return
         name, text = args
         o = self.objects_dic[name]
-        x = self.get_x(o, True, True)  + C.TEXT_MARGIN_X
-        y = self.ypos - C.TEXT_MARGIN_Y
+        x = self.get_x(o, True, True)  + self.cfg.TEXT_MARGIN_X
+        y = self.ypos - self.cfg.TEXT_MARGIN_Y
         self.add(1, self.gfx.text, x, y, text)
-        self.ypos += C.STEP_SMALL
+        self.ypos += self.cfg.STEP_SMALL
 
     def handle_lconstraint_below(self, cmd, args):
         if cmd != 'lconstraint_below': return
         name, text = args
         o = self.objects_dic[name]
-        x = self.get_x(o, True, True) + C.TEXT_MARGIN_X
-        y = self.ypos - C.TEXT_MARGIN_Y + C.STEP_SMALL
+        x = self.get_x(o, True, True) + self.cfg.TEXT_MARGIN_X
+        y = self.ypos - self.cfg.TEXT_MARGIN_Y + self.cfg.STEP_SMALL
         self.add(1, self.gfx.text, x, y, text)
 
     def handle_active(self, cmd, args):
@@ -227,17 +228,17 @@ class UmlBuilder:
     def handle_cmessage(self, cmd, args):
         if cmd != 'cmessage': return
         src, dst, label, message, asynch = args
-        self.ypos += C.STEP_NORMAL
+        self.ypos += self.cfg.STEP_NORMAL
         save1_y = self.ypos
         self.handle_object('object', (dst, label))  # create
         self.last_cmd = 'object'
 
         self.handle_object('', None)  # draw
         save2_y = self.ypos
-        self.ypos = save1_y - C.OBJECT_STEP/2
+        self.ypos = save1_y - self.cfg.OBJECT_STEP/2
         text = message or "«create»"
         self._handle_message(src, dst, text, True, True,
-                             shorten=C.COLUMN_WIDTH/2)
+                             shorten=self.cfg.COLUMN_WIDTH/2)
         self.ypos = save2_y
 
     def handle_dmessage(self, cmd, args):
@@ -247,10 +248,10 @@ class UmlBuilder:
         self._handle_message(src, dst, text, True, True)
         o = self.objects_dic[dst]
         x = self.get_x(o, True)
-        self.add(2, self.gfx.cross, x, self.ypos, C.CROSS_SIZE)
+        self.add(2, self.gfx.cross, x, self.ypos, self.cfg.CROSS_SIZE)
 
         self.handle_complete('complete', [dst])
-        self.ypos += C.STEP_NORMAL
+        self.ypos += self.cfg.STEP_NORMAL
 
 
     def handle_rmessage(self, cmd, args):
@@ -260,7 +261,7 @@ class UmlBuilder:
 
     def _handle_message(self, src, dst, txt, dashed, asynch,
                         shorten=0, align=''):
-        self.ypos += C.STEP_NORMAL
+        self.ypos += self.cfg.STEP_NORMAL
         o1 = self.objects_dic[src]
         o2 = self.objects_dic[dst]
         inv = o1.index >= o2.index
@@ -270,22 +271,22 @@ class UmlBuilder:
 
         if src == dst:
             if txt:
-                x = self.get_x(o1, True, True) + C.TEXT_MARGIN_X
+                x = self.get_x(o1, True, True) + self.cfg.TEXT_MARGIN_X
                 y = self.ypos
                 self.add(2, self.gfx.text, x, y, txt)
 
             sgn = 1
             x0 = self.get_x(o1, True, True)
-            xa = x0 + C.MESSAGE_SPACING
-            xb = x0 + C.COLUMN_WIDTH / 2
-            x1 = x0 + C.MESSAGE_SPACING
-            step = C.STEP_NORMAL
-            xtext = x0 + C.TEXT_MARGIN_Y
+            xa = x0 + self.cfg.MESSAGE_SPACING
+            xb = x0 + self.cfg.COLUMN_WIDTH / 2
+            x1 = x0 + self.cfg.MESSAGE_SPACING
+            step = self.cfg.STEP_NORMAL
+            xtext = x0 + self.cfg.TEXT_MARGIN_Y
 
             # "U" line
             points = [
-                (xa, self.ypos + C.TEXT_MARGIN_Y),
-                (xb, self.ypos + C.TEXT_MARGIN_Y),
+                (xa, self.ypos + self.cfg.TEXT_MARGIN_Y),
+                (xb, self.ypos + self.cfg.TEXT_MARGIN_Y),
                 (xb, self.ypos + step),
                 (x1, self.ypos + step),
             ]
@@ -295,10 +296,10 @@ class UmlBuilder:
             if txt:
                 start = middle = end = False
                 if align == '(':
-                    x = self.get_x(o1, True, True) + C.TEXT_MARGIN_X
+                    x = self.get_x(o1, True, True) + self.cfg.TEXT_MARGIN_X
                     start = True
                 elif align == ')':
-                    x = self.get_x(o2, True) - C.TEXT_MARGIN_Y - shorten
+                    x = self.get_x(o2, True) - self.cfg.TEXT_MARGIN_Y - shorten
                     end = True
                 else:
                     x = (self.get_x(o1, True) + self.get_x(o2, True) - shorten)/2
@@ -306,32 +307,32 @@ class UmlBuilder:
                 y = self.ypos
                 self.add(2, self.gfx.text, x, y, txt,
                          start=start, middle=middle, end=end)
-                self.ypos += C.TEXT_MARGIN_Y
+                self.ypos += self.cfg.TEXT_MARGIN_Y
 
-            x1 = self.get_x(o1, True, True) + C.MESSAGE_SPACING
-            x2 = self.get_x(o2, True) - shorten - C.MESSAGE_SPACING
-            x2 -= C.ACTIVITY_WIDTH / 2 if self.nb_active(o2.name) else 0
+            x1 = self.get_x(o1, True, True) + self.cfg.MESSAGE_SPACING
+            x2 = self.get_x(o2, True) - shorten - self.cfg.MESSAGE_SPACING
+            x2 -= self.cfg.ACTIVITY_WIDTH / 2 if self.nb_active(o2.name) else 0
 
             # head line
-            if inv: x1 += C.MESSAGE_SPACING
-            else: x2 -= C.MESSAGE_SPACING
+            if inv: x1 += self.cfg.MESSAGE_SPACING
+            else: x2 -= self.cfg.MESSAGE_SPACING
             self.add(2, self.gfx.line, x1, self.ypos, x2, self.ypos, dashed=dashed)
-            if inv: x1 -= C.MESSAGE_SPACING
-            else: x2 += C.MESSAGE_SPACING
+            if inv: x1 -= self.cfg.MESSAGE_SPACING
+            else: x2 += self.cfg.MESSAGE_SPACING
 
         # arrow head
         self.add(2, self.gfx.arrow_head, x1 if inv else x2, self.ypos,
-                 C.ARROW_HEAD_SIZE, not asynch, inv)
+                 self.cfg.ARROW_HEAD_SIZE, not asynch, inv)
 
     def handle_step(self, cmd, args):
         if cmd != 'step': return
-        self.ypos += C.STEP_NORMAL
+        self.ypos += self.cfg.STEP_NORMAL
 
     def handle_blip(self, cmd, args):
         if cmd != 'blip': return
         name, = args
         self.handle_active('active', [name])
-        self.ypos += C.STEP_NORMAL
+        self.ypos += self.cfg.STEP_NORMAL
         self.handle_inactive('inactive', [name])
 
     def handle_comment(self, cmd, args):
@@ -340,14 +341,14 @@ class UmlBuilder:
         comment_name, pos = options
 
         o = self.objects_dic[name]
-        height = len(text.split('\n')) * C.TEXT_HEIGHT + C.TEXT_MARGIN_Y
+        height = len(text.split('\n')) * self.cfg.TEXT_HEIGHT + self.cfg.TEXT_MARGIN_Y
         x1, y1 = self.get_x(o, True), self.ypos
         x2, y2 = x1, y1 - height/2
-        x2offset = C.COLUMN_WIDTH/4
+        x2offset = self.cfg.COLUMN_WIDTH/4
 
         lines = text.split('\n')
         length = max([self.gfx.get_text_width(l) for l in lines])
-        width = length + C.TEXT_MARGIN_X + C.TEXT_DOGEAR
+        width = length + self.cfg.TEXT_MARGIN_X + self.cfg.TEXT_DOGEAR
 
         pos_terms = RX_COMMENT_POS.findall(pos)
         for key, value in pos_terms:
@@ -370,14 +371,14 @@ class UmlBuilder:
         if comment_name:
             self.comment_dic[comment_name] = comment
 
-        self.add(3, self.gfx.comment_box, x2, y2, width, height, C.TEXT_DOGEAR)
+        self.add(3, self.gfx.comment_box, x2, y2, width, height, self.cfg.TEXT_DOGEAR)
         self.make_comment_connector(x1, y1, comment)
 
-        dx = C.TEXT_MARGIN_X
-        dy = C.TEXT_HEIGHT
+        dx = self.cfg.TEXT_MARGIN_X
+        dy = self.cfg.TEXT_HEIGHT
         for line in lines:
             self.add(3, self.gfx.text, x2+dx, y2+dy, line, light=True)
-            dy += C.TEXT_HEIGHT
+            dy += self.cfg.TEXT_HEIGHT
 
     def make_comment_connector(self, x, y, comment):
         if comment.x > x:
@@ -420,46 +421,46 @@ class UmlBuilder:
                 else:
                     self.warn(cmd, args,
                               f'Unknown option "{key} {value}"')
-        self.ypos += C.STEP_SMALL
+        self.ypos += self.cfg.STEP_SMALL
         o = self.objects_dic[src]
         x = self.get_x(o)
         y = self.ypos
         self.frame_dic[fname] = Frame(x, y, label, out)
-        self.ypos += C.STEP_NORMAL
+        self.ypos += self.cfg.STEP_NORMAL
 
     def handle_end_frame(self, cmd, args):
         if cmd != 'end_frame': return
         fname, dst = args
         o = self.objects_dic.get(dst) or self.dead_objects_dic.get(dst)
         frame = self.frame_dic[fname]
-        self.ypos += C.STEP_SMALL
+        self.ypos += self.cfg.STEP_SMALL
         x1, x2 = frame.xpos, self.get_x(o)
         if x1 > x2: x1, x2 = x2, x1
         x, y = x1, frame.ypos
-        w, h = x2 + C.COLUMN_WIDTH - x, self.ypos - y
+        w, h = x2 + self.cfg.COLUMN_WIDTH - x, self.ypos - y
         if frame.out:
             x -= frame.out
             w += frame.out*2
 
         self.add(2, self.gfx.rect, x, y, w, h, transparent=True, grey=True)
-        d = C.TEXT_DOGEAR
-        width = self.gfx.get_text_width(frame.label) + C.TEXT_MARGIN_X*2 + d
-        height = C.TEXT_HEIGHT + C.TEXT_MARGIN_Y
+        d = self.cfg.TEXT_DOGEAR
+        width = self.gfx.get_text_width(frame.label) + self.cfg.TEXT_MARGIN_X*2 + d
+        height = self.cfg.TEXT_HEIGHT + self.cfg.TEXT_MARGIN_Y
         self.add(2, self.gfx.frame_label_box, x, y, width, height, d)
 
-        dx = C.TEXT_MARGIN_X
-        dy = C.TEXT_HEIGHT
+        dx = self.cfg.TEXT_MARGIN_X
+        dy = self.cfg.TEXT_HEIGHT
         self.add(2, self.gfx.text, x+dx, y+dy, frame.label, light=True)
-        self.ypos += C.STEP_SMALL
+        self.ypos += self.cfg.STEP_SMALL
 
     def handle_delete(self, cmd, args):
         if cmd != 'delete': return
         name, = args
         o = self.objects_dic[name]
         x = self.get_x(o, True)
-        self.add(2, self.gfx.cross, x, self.ypos + C.CROSS_SIZE/2, C.CROSS_SIZE)
+        self.add(2, self.gfx.cross, x, self.ypos + self.cfg.CROSS_SIZE/2, self.cfg.CROSS_SIZE)
         self.handle_complete('complete', [name])
-        self.ypos += C.STEP_NORMAL
+        self.ypos += self.cfg.STEP_NORMAL
 
     def handle_complete(self, cmd, args):
         if cmd == 'complete':
@@ -472,14 +473,14 @@ class UmlBuilder:
             o = self.objects_dic[name]
             if o.label is not None:
                 x = self.get_x(o, True)
-                y1 = o.ypos + C.STEP_NORMAL
+                y1 = o.ypos + self.cfg.STEP_NORMAL
                 y2 = self.ypos + .1
                 self.add(1, self.gfx.line, x, y1, x, y2,dashed=True, grey=True)
             self.dead_objects_dic[name] = self.objects_dic[name]
             del self.objects_dic[name]
 
         elif self.last_cmd == 'complete':
-            self.ypos += C.STEP_NORMAL
+            self.ypos += self.cfg.STEP_NORMAL
 
     def handle_cmd(self, cmd, args):
         if cmd == '#####':
@@ -514,15 +515,15 @@ class UmlBuilder:
 
     def inactivate(self, name):
         o = self.objects_dic[name]
-        x = self.get_x(o, True) + self.nb_active(name)*C.ACTIVITY_WIDTH/2 \
-            - C.ACTIVITY_WIDTH
+        x = self.get_x(o, True) + self.nb_active(name)*self.cfg.ACTIVITY_WIDTH/2 \
+            - self.cfg.ACTIVITY_WIDTH
         if not len(self.activity_dic[name]):
             error(f'Cannot inactivate {name} because it is not active', self)
         y = self.activity_dic[name][-1]
-        w = C.ACTIVITY_WIDTH
+        w = self.cfg.ACTIVITY_WIDTH
         h = self.ypos-self.activity_dic[name][-1]
         if h == 0:
-            self.ypos += C.STEP_NORMAL
+            self.ypos += self.cfg.STEP_NORMAL
             h = self.ypos-self.activity_dic[name][-1]
         self.activity_boxes.append((x, y, w, h))
         self.activity_dic[name].pop()
